********************************************************************************
/* 
This do file cleans data for the public release (both paper 1 and paper 2)

IMPORTANT: This is an internal do file (not to be included as part of the replication package) because it calls files that have sensitive information. 
For such files, this do file extracts only the public covariates that we need.
*/
********************************************************************************

clear all

********************************************************************************
**# 0. Define file paths 
********************************************************************************

local networks "${dropbox}/outside/Networks and Social Mobility"
local replication_folder "`networks'/data_release/Austin_In_Progress"

* Latest FB data
local darkhorse_datasets "`networks'/data_release_v3/DarkHorse Datasets"

* Public covariates in the public replication package 
local public_replication_covariates "`replication_folder'/Other public covariate data" 

* FB data in the public replication package 
local public_replication_FB_data "`replication_folder'/Social Capital Data"


********************************************************************************
**# 1. Clean county-level data
********************************************************************************

local geo county

*==============================================================================*
**## 1.1. Clean FB data 
*==============================================================================*

* Get county weights 
use "`networks'/County Level Social Capital/raw data/from_finer_geos/county_outcomes_dta.dta", clear
tostring state, gen(state_fips)
tostring county, gen(county_fips)

replace county_fips = "00" + county_fips if length(county_fips) == 1
replace county_fips = "0" + county_fips if length(county_fips) == 2
gen fips = state_fips + county_fips
replace fips = "0" + fips if length(fips) == 4

drop state county state_fips county_fips 
rename fips county

keep county kid_pooled_pooled_blw_p50_n
destring county, replace
isid county 

tempfile county_weight
save `county_weight'


* Get county pop 
use "`networks'/County Level Social Capital/derived data/acs_income_race_segregation.dta", replace 
keep county pop2018 

tempfile county_pop 
save `county_pop'


* Merge pop and weight to social capital data 
use "`darkhorse_datasets'/social_capital_`geo'_updated.dta", clear
merge 1:1 county using `county_weight', keep(master match) nogen 
merge 1:1 county using `county_pop', keep(master match) nogen


* Order variables according to data dictionary
order county county_name kid_pooled_pooled_blw_p50_n pop2018 ec ec_std_err childhood_ec childhood_ec_std_err only_group_ec ec_high ec_high_std_err childhood_ec_high childhood_ec_high_std_err ///
only_group_ec_high only_group_ec_exposure only_group_ec_high_exposure childhood_ec_exposure childhood_ec_high_exposure only_group_ec_bias only_group_ec_high_bias childhood_ec_bias childhood_ec_high_bias ///
clustering support_ratio volunteering civic_organizations


* Rename variables for consistency with data dictionary
rename kid_pooled_pooled_blw_p50_n num_below_p50
rename ec ec_`geo'
rename ec_std_err ec_se_`geo'
rename childhood_ec child_ec_`geo'
rename childhood_ec_std_err child_ec_se_`geo'
rename only_group_ec ec_grp_mem_`geo'
rename ec_high ec_high_`geo'
rename ec_high_std_err ec_high_se_`geo'
rename childhood_ec_high child_high_ec_`geo'
rename childhood_ec_high_std_err child_high_ec_se_`geo'
rename only_group_ec_high ec_grp_mem_high_`geo'
rename only_group_ec_exposure exposure_grp_mem_`geo'
rename only_group_ec_high_exposure exposure_grp_mem_high_`geo'
rename childhood_ec_exposure child_exposure_`geo'
rename childhood_ec_high_exposure child_high_exposure_`geo'
rename only_group_ec_bias bias_grp_mem_`geo'
rename only_group_ec_high_bias bias_grp_mem_high_`geo'
rename childhood_ec_bias child_bias_`geo'
rename childhood_ec_high_bias child_high_bias_`geo'
rename clustering clustering_`geo'
rename support_ratio support_ratio_`geo'
rename volunteering_rate volunteering_rate_`geo'
rename civic_organizations civic_organizations_`geo'

label var county "5-digit county FIPS"
label var county_name "County name"
label var num_below_p50 "No. of children with below-median parental household income"
label var pop2018 "Population in 2018"

label var ec_`geo' "Economic connectedness"
label var ec_se_`geo' "Std. err. of economic connectedness"
label var child_ec_`geo' "Childhood economic connectedness"
label var child_ec_se_`geo' "Std. err. of childhood economic connectedness"
label var ec_grp_mem_`geo' "Economic connectedness (friend groups)"
label var ec_high_`geo' "Economic connectedness (for high-SES individuals)"
label var ec_high_se_`geo' "Std. err. of economic connectedness (for high-SES individuals)"
label var child_high_ec_`geo' "Childhood economic connectedness (for high-SES individuals)"
label var child_high_ec_se_`geo' "Std. err. of childhood economic connectedness (for high-SES individuals)"
label var ec_grp_mem_high_`geo' "Economic connectedness (friend groups; for high-SES individuals)"
label var exposure_grp_mem_`geo' "Exposure (friend groups)"
label var exposure_grp_mem_high_`geo' "Exposure (friend groups; for high-SES individuals)"
label var child_exposure_`geo' "Exposure in childhood"
label var child_high_exposure_`geo' "Exposure in childhood (for high-SES individuals)"
label var bias_grp_mem_`geo' "Friending bias (friend groups)"
label var bias_grp_mem_high_`geo' "Friending bias (friend groups; for high-SES individuals)"
label var child_bias_`geo' "Friending bias in childhood"
label var child_high_bias_`geo' "Friending bias in childhood (for high-SES individuals)"
label var clustering_`geo' "Clustering"
label var support_ratio_`geo' "Support ratio"
label var volunteering_rate_`geo' "Volunteering rate"
label var civic_organizations_`geo' "Civic organizations"


compress
save "`public_replication_FB_data'/social_capital_`geo'.dta", replace


*==============================================================================*
**## 1.2 Clean public covariate data 
*==============================================================================*

* Our internal master dataset County Level Social Capital/derived data/countySocCapAndOutcomeMeasures_jan_plus_log_crr.dta has fewer obs. than the no. of obs. we have mobility data for 
* This leads to some awkwardness because the full set of counties for which we have mobility data is publicly available on the Opp. Atlas (as well as with Darkhorse)
* Get as many nonmissing outcome variables as possible.

*------------------------------------------------------------------------------*
* Get population and segregation 
*------------------------------------------------------------------------------*
use "`networks'/County Level Social Capital/derived data/acs_income_race_segregation.dta", replace 
drop income_segregation
rename income_segregation50 income_segregation
replace income_segregation = . if income_segregation == 0 | pop2018 < 20000
replace racial_segregation = . if racial_segregation == 0 | pop2018 < 20000

keep county income_segregation racial_segregation pop2018 
tempfile county_segregation 
save `county_segregation'


*------------------------------------------------------------------------------*
* Get causal estimates  
*------------------------------------------------------------------------------*
use "`networks'/County Level Social Capital/raw data/from_finer_geos/online_table4-2.dta", clear 

keep cty2000 causal_p25_cz_cty_kr26 causal_p25_cz_cty_kr26_se
rename cty2000 county 

tempfile county_causal
save `county_causal'


*------------------------------------------------------------------------------*
* Get county mobility outcomes + weights + teenage birth
*------------------------------------------------------------------------------*
use "`networks'/County Level Social Capital/raw data/from_finer_geos/county_outcomes_dta.dta", clear
tostring state, gen(state_fips)
tostring county, gen(county_fips)

replace county_fips = "00" + county_fips if length(county_fips) == 1
replace county_fips = "0" + county_fips if length(county_fips) == 2
gen fips = state_fips + county_fips
replace fips = "0" + fips if length(fips) == 4

drop state county state_fips county_fips 
rename fips county

keep county cz czname teenbrth_pooled_female_p25 kfr_pooled_pooled_p25 kfr_black_pooled_p25 kfr_white_pooled_p25 kfr_26_pooled_pooled_p25 kid_pooled_pooled_blw_p50_n kid_white_pooled_blw_p50_n kid_black_pooled_blw_p50_n
destring county, replace 
isid county

tempfile county_outcomes
save `county_outcomes'


*------------------------------------------------------------------------------*
* Get Gini coefficient 
*------------------------------------------------------------------------------*
use "`networks'/County Level Social Capital/raw data/land_of_opportunity/onlinedata3.dta", clear 

gen gini99_simple = gini - inc_share_1perc

keep county_id gini99_simple
rename county_id county 

tempfile county_gini 
save `county_gini'


*------------------------------------------------------------------------------*
* Get remaining covariates (aggregated from tract)
*------------------------------------------------------------------------------*
use "`networks'/County Level Social Capital/raw data/from_finer_geos/covariates_tract_wide.dta", clear 

keep state10 county10 jobs_total_5mi_2015 job_growth_2004_2013 emp2000 hhinc_mean2010 singleparent_share2000 gsmn_math_g3_2013 frac_coll_plus2000 poor_share2000 nonpoor_share2000 ///
share_white2000 share_asian2000 share_black2000 share_hisp2000 share_white2017 share_black2017 share_hisp2017 med_hhinc2000 med_hhinc2017 pop2000

tostring state10, gen(state_fips)
tostring county10, gen(county_fips)

replace county_fips = "00" + county_fips if length(county_fips) == 1
replace county_fips = "0" + county_fips if length(county_fips) == 2
gen fips = state_fips + county_fips
replace fips = "0" + fips if length(fips) == 4

drop state10 county10 state_fips county_fips 
rename fips county
destring county, replace 

collapse (mean) jobs_total_5mi_2015 job_growth_2004_2013 emp2000 hhinc_mean2010 singleparent_share2000 gsmn_math_g3_2013 frac_coll_plus2000 poor_share2000 nonpoor_share2000 ///
share_white2000 share_asian2000 share_black2000 share_hisp2000 share_white2017 share_black2017 share_hisp2017 med_hhinc2000 med_hhinc2017 (rawsum) pop2000 [aweight = pop2000], by(county)

tempfile county_covs 
save `county_covs'


*------------------------------------------------------------------------------*
* Merge 
*------------------------------------------------------------------------------*

use `county_segregation', clear 
merge 1:1 county using `county_causal', nogen 
merge 1:1 county using `county_outcomes', nogen 
merge 1:1 county using `county_gini', nogen 
merge 1:1 county using `county_covs', nogen 


*------------------------------------------------------------------------------*
* Labels 
*------------------------------------------------------------------------------*

label var county "5-digit County FIPS"
label var income_segregation "Income segregation (Theil entropy index)"
label var racial_segregation "Racial segregation (Theil H-index)"
label var pop2018 "Population in 2018"
label var pop2000 "Population in 2000"
label var causal_p25_cz_cty_kr26 "Causal place effect estimate (Chetty and Hendren 2018b)"
label var causal_p25_cz_cty_kr26_se "Std. err. of causal place effect estimate (Chetty and Hendren 2018b)"
label var kfr_black_pooled_p25 "Mean pctile rank in the national distribution of household income in 2014-2015 (Black)"
label var kfr_white_pooled_p25 "Mean pctile rank in the national distribution of household income in 2014-2015 (white)"
label var kid_black_pooled_blw_p50_n "Number of children under 18 with parents with HH inc. below the median (Black)"
label var kid_white_pooled_blw_p50_n "Number of children under 18 with parents with HH inc. below the median (white)"
label var jobs_total_5mi_2015 "Jobs within 5 miles"
label var job_growth_2004_2013 "Job growth 2004-2013"
label var emp2000 "2000 Employment Rate"
label var gsmn_math_g3_2013 "Mean 3rd grade math score"
label var frac_coll_plus2000 "Share college grad."
label var singleparent_share2000 "Share of single parent households"
label var gini99_simple "Income inequality (Gini coefficient)"
label var poor_share2000 "Share poor" 
label var nonpoor_share2000 "1 - share poor"
label var share_white2000 "Share white (2000)"
label var share_asian2000 "Share Asian (2000)"
label var share_black2000 "Share Black (2000)"
label var share_hisp2000 "Share Hispanic (2000)"
label var share_white2017 "Share white (2017)"
label var share_black2017 "Share Black (2017)"
label var share_hisp2017 "Share Hispanic (2017)"
label var med_hhinc2000 "Median HH income (2000)"
label var med_hhinc2017 "Median HH income (2017)"


rename kid_pooled_pooled_blw_p50_n num_below_p50

compress
save "`public_replication_covariates'/`geo'_covariates.dta", replace


*==============================================================================*
**## 1.3 Clean health data from Chetty et al. (2016)
*==============================================================================*

use "`networks'/County Level Social Capital/raw data/chetty_jama_paper/health_ineq_online_table_11.dta", clear
rename cty county 

compress 
save "`public_replication_covariates'/chetty_2016_JAMA_table_11.dta", replace


********************************************************************************
**# 2. Clean ZCTA-level data
********************************************************************************

local geo zip

*==============================================================================*
**## 2.1. Clean FB data 
*==============================================================================*

use "`darkhorse_datasets'/social_capital_zcta_updated.dta", clear

* Merge pop and weight to social capital data 
merge 1:1 zcta using "`networks'/County Level Social Capital/derived data/zctaSocCapAndOutcomeMeasures_jan_plus_log_crr.dta", keep(master match) keepusing(kid_pooled_pooled_blw_p50_n pop_2018) nogen


* Order variables according to data dictionary
order zcta county kid_pooled_pooled_blw_p50_n pop_2018 ec ec_std_err nbhd_ec only_group_ec ec_high ec_high_std_err ///
nbhd_ec_high only_group_ec_high only_group_ec_exposure only_group_ec_high_exposure nbhd_ec_exposure only_group_ec_bias only_group_ec_high_bias nbhd_ec_bias nbhd_ec_high_bias ///
clustering support_ratio volunteering_rate civic_organizations

* Rename variables for consistency with data dictionary
rename zcta zip                                                                 // for consistency with data dictionary
rename pop_2018 pop2018
rename kid_pooled_pooled_blw_p50_n num_below_p50
rename ec ec_`geo'
rename ec_std_err ec_se_`geo'
rename nbhd_ec nbhd_ec_`geo'
rename only_group_ec ec_grp_mem_`geo'
rename ec_high ec_high_`geo'
rename ec_high_std_err ec_high_se_`geo'
rename nbhd_ec_high nbhd_ec_high_`geo'
rename only_group_ec_high ec_grp_mem_high_`geo'
rename only_group_ec_exposure exposure_grp_mem_`geo'
rename only_group_ec_high_exposure exposure_grp_mem_high_`geo'
rename nbhd_ec_exposure nbhd_exposure_`geo'
rename only_group_ec_bias bias_grp_mem_`geo'
rename only_group_ec_high_bias bias_grp_mem_high_`geo'
rename nbhd_ec_bias nbhd_bias_`geo'
rename nbhd_ec_high_bias nbhd_bias_high_`geo'
rename clustering clustering_`geo'
rename support_ratio support_ratio_`geo'
rename volunteering_rate volunteering_rate_`geo'
rename civic_organizations civic_organizations_`geo'

label var zip "ZCTA"                                                        


compress
save "`public_replication_FB_data'/social_capital_`geo'.dta", replace


*==============================================================================*
**## 2.2 Clean public covariate data 
*==============================================================================*
	
use "`networks'/County Level Social Capital/derived data/zctaSocCapAndOutcomeMeasures_jan_plus_log_crr.dta", clear

destring zcta, replace
isid zcta                                                                       // the zcta should be a unique identifier in this dataset

keep zcta county kid_pooled_pooled_blw_p50_n kfr_pooled_pooled_p25 kfr_26_pooled_pooled_p25 kid_black_pooled_blw_p50_n kfr_black_pooled_p25 kid_white_pooled_blw_p50_n kfr_white_pooled_p25 pop_2000_n ///
jobs_total_5mi_2015 jobs_highpay_5mi_2015 job_growth_2004_2013 emp2000 hhinc_mean1990 hhinc_mean2010 singleparent_share2000 gsmn_math_g3_2013 frac_coll_plus2000 ///
poor_share2000 nonpoor_share2000 poor_share2010 hhinc_mean2000 share_white2000 share_asian2000 share_black2000 share_hisp2000 pop_2018 med_hhinc2000 med_inc_2018 ///
share_white_2018 share_black_2018 share_natam_2018 share_asian_2018 share_hawaii_2018 share_hispanic_2018 cz


rename zcta zip                                                                 // for consistency with data dictionary
rename kid_pooled_pooled_blw_p50_n num_below_p50
rename pop_2018 pop2018


label var zip "ZCTA" 
label var county "5-digit county FIPS"
label var cz "Commuting Zone"
label var num_below_p50 "Number of children under 18 with parents with HH inc. below the median"
label var kfr_pooled_pooled_p25 "Mean pctile rank in the national distribution of household income in 2014-2015"
label var pop2018 "Population in 2018"
label var pop_2000_n "Population in 2000"
label var kfr_black_pooled_p25 "Mean pctile rank in the national distribution of household income in 2014-2015 (Black)"
label var kfr_white_pooled_p25 "Mean pctile rank in the national distribution of household income in 2014-2015 (white)"
label var kfr_26_pooled_pooled_p25 "Mean pctile rank in the national distribution of HH income at age 26"
label var kid_black_pooled_blw_p50_n "Number of children under 18 with parents with HH inc. below the median (Black)"
label var kid_white_pooled_blw_p50_n "Number of children under 18 with parents with HH inc. below the median (white)"
label var jobs_total_5mi_2015 "Jobs within 5 miles"
label var job_growth_2004_2013 "Job growth 2004-2013"
label var emp2000 "2000 Employment Rate"
label var gsmn_math_g3_2013 "Mean 3rd grade math score"
label var frac_coll_plus2000 "Share college grad."
label var singleparent_share2000 "Share of single parent households"
label var poor_share2000 "Share poor (2000)" 
label var nonpoor_share2000 "1 - share poor (2000)"
label var poor_share2010 "Share poor (2010)"
label var share_white2000 "Share white (2000)"
label var share_asian2000 "Share Asian (2000)"
label var share_black2000 "Share Black (2000)"
label var share_hisp2000 "Share Hispanic (2000)"
label var share_white_2018 "Share white (2018)"
label var share_black_2018 "Share Black (2018)" 
label var share_natam_2018 "Share Native American (2018)"
label var share_asian_2018 "Share Asian (2018)"
label var share_hawaii_2018 "Share Hawaiian (2018)"
label var share_hispanic_2018 "Share Hispanic (2018)"
label var med_hhinc2000 "Median HH income (2000)"
label var med_inc_2018 "Median HH income (2018)"
label var hhinc_mean2000 "Mean HH income (2000)"


compress
save "`public_replication_covariates'/zip_covariates.dta", replace


*==============================================================================*
**## 2.3 Clean NHGIS income data
*==============================================================================*

import delimited "`networks'/County Level Social Capital/raw data/nhgis_income/zcta_income_bins_and_median_income_by_age_14_18.csv", clear


keep ajzle019-ajzle035 ajzme003 zcta5a
rename zcta5a zip

label var zip "ZCTA"

label var ajzle019 "No. of householders 25 to 44 years"
label var ajzle020 "No. of householders 25 to 44 years with less than $10,000 HH income"
label var ajzle021 "No. of householders 25 to 44 years with $10,000-$14,999 HH income"
label var ajzle022 "No. of householders 25 to 44 years with $15,000-$19,999 HH income"
label var ajzle023 "No. of householders 25 to 44 years with $20,000-$24,999 HH income"
label var ajzle024 "No. of householders 25 to 44 years with $25,000-$29,999 HH income"
label var ajzle025 "No. of householders 25 to 44 years with $30,000-$34,999 HH income"
label var ajzle026 "No. of householders 25 to 44 years with $35,000-$39,999 HH income"
label var ajzle027 "No. of householders 25 to 44 years with $40,000-$44,999 HH income"
label var ajzle028 "No. of householders 25 to 44 years with $45,000-$49,999 HH income"
label var ajzle029 "No. of householders 25 to 44 years with $50,000-$59,999 HH income"
label var ajzle030 "No. of householders 25 to 44 years with $60,000-$74,999 HH income"
label var ajzle031 "No. of householders 25 to 44 years with $75,000-$99,999 HH income"
label var ajzle032 "No. of householders 25 to 44 years with $100,000-$124,999 HH income"
label var ajzle033 "No. of householders 25 to 44 years with $125,000-$149,999 HH income"
label var ajzle034 "No. of householders 25 to 44 years with $150,000-$199,999 HH income"
label var ajzle035 "No. of householders 25 to 44 years with $200,000 or more HH income"

label var ajzme003 "Median household income for householders 25 to 44 years"

order zip ajzme003 ajzle019-ajzle035


compress 
save "`public_replication_covariates'/zip_income_bins_and_median_income_by_age_14_18.dta", replace


********************************************************************************
**# 3. Clean high school-level data
********************************************************************************

local geo hs

*==============================================================================*
**## 3.1. Clean FB data 
*==============================================================================*

use "`darkhorse_datasets'/social_capital_high_school_updated.dta", clear

rename high_school nces_school_id
merge 1:1 nces_school_id using "`networks'/County Level Social Capital/raw data/fb_collapses/raw dta/nces_highschools.dta", keep(master match) keepusing(students_9_to_12) nogen
rename nces_school_id high_school


* Order variables according to data dictionary
order high_school name zcta fips longitude latitude students_9_to_12 ///
ec_own_ses ec_own_ses_std_err ec_parent_ses ec_parent_ses_std_err ec_high_own_ses ec_high_own_ses_std_err ec_high_parent_ses ec_high_parent_ses_std_err ///
exposure_own_ses exposure_parent_ses bias_own_ses bias_parent_ses bias_high_own_ses bias_high_parent_ses clustering support_ratio volunteering_rate

* Rename variables for consistency with data dictionary 
rename name high_school_name 
rename zcta zip                                                                 // for consistency with data dictionary
rename fips county 
rename ec_own_ses ec_own_ses_`geo'
rename ec_own_ses_std_err ec_own_ses_se_`geo'
rename ec_parent_ses ec_parent_ses_`geo'
rename ec_parent_ses_std_err ec_parent_ses_se_`geo'
rename ec_high_own_ses ec_high_own_ses_`geo'
rename ec_high_own_ses_std_err ec_high_own_ses_se_`geo'
rename ec_high_parent_ses ec_high_parent_ses_`geo'
rename ec_high_parent_ses_std_err ec_high_parent_ses_se_`geo'
rename exposure_own_ses exposure_own_ses_`geo'
rename exposure_parent_ses exposure_parent_ses_`geo'
rename bias_own_ses bias_own_ses_`geo'
rename bias_parent_ses bias_parent_ses_`geo'
rename bias_high_own_ses bias_high_own_ses_`geo'
rename bias_high_parent_ses bias_high_parent_ses_`geo'
rename clustering clustering_`geo'
rename support_ratio support_ratio_`geo'
rename volunteering_rate volunteering_rate_`geo'

label var zip "ZCTA"

* Drop support ratio - we are not releasing this at the high school level
drop support_ratio_`geo'

* Drop coordinates due to Meta 
drop longitude latitude

compress
save "`public_replication_FB_data'/social_capital_high_school.dta", replace


*==============================================================================*
**## 3.2 Clean NCES data
*==============================================================================*

use "`networks'/County Level Social Capital/raw data/fb_collapses/raw dta/nces_highschools.dta", clear 


drop hhi_hs 
label var frac_students_fr_red_lunch_5yr_m "Share of students eligible for free or reduced lunch"


compress 
save "`public_replication_covariates'/nces_highschools.dta", replace


*==============================================================================*
**## 3.3 Clean CRDC data
*==============================================================================*

use "`networks'/County Level Social Capital/raw data/school_characteristics/crdc_nces_collapse_hs_new.dta", clear 

drop high_school nces_school_id dups
label var nces_id "NCES School ID"

compress 
save "`public_replication_covariates'/crdc_nces_collapse_hs.dta", replace


********************************************************************************
**# 4. Clean college-level data
********************************************************************************

local geo college

*==============================================================================*
**## 4.1. Clean FB data 
*==============================================================================*

use "`darkhorse_datasets'/social_capital_college_updated.dta", clear


replace college = college / 100
merge 1:1 college using "`networks'/County Level Social Capital/raw data/college_characteristics/college_characteristics.dta", keep(master match) keepusing(count) nogen
replace college = college * 100


* Order variables according to data dictionary
order college name zcta fips longitude latitude count ///
ec_own_ses ec_own_ses_std_err ec_parent_ses ec_parent_ses_std_err ec_high_own_ses ec_high_own_ses_std_err ec_high_parent_ses ec_high_parent_ses_std_err ///
exposure_own_ses exposure_parent_ses bias_own_ses bias_parent_ses bias_high_own_ses bias_high_parent_ses clustering support_ratio volunteering_rate

* Rename variables for consistency with data dictionary 
rename name college_name 
rename zcta zip                                                                 // for consistency with data dictionary
rename fips county 
rename count mean_students_per_cohort

rename ec_own_ses ec_own_ses_`geo'
rename ec_own_ses_std_err ec_own_ses_se_`geo'
rename ec_parent_ses ec_parent_ses_`geo'
rename ec_parent_ses_std_err ec_parent_ses_se_`geo'
rename ec_high_own_ses ec_high_own_ses_`geo'
rename ec_high_own_ses_std_err ec_high_own_ses_se_`geo'
rename ec_high_parent_ses ec_high_parent_ses_`geo'
rename ec_high_parent_ses_std_err ec_high_parent_ses_se_`geo'
rename exposure_own_ses exposure_own_ses_`geo'
rename exposure_parent_ses exposure_parent_ses_`geo'
rename bias_own_ses bias_own_ses_`geo'
rename bias_parent_ses bias_parent_ses_`geo'
rename bias_high_own_ses bias_high_own_ses_`geo'
rename bias_high_parent_ses bias_high_parent_ses_`geo'
rename clustering clustering_`geo'
rename support_ratio support_ratio_`geo'
rename volunteering_rate volunteering_rate_`geo'

label var zip "ZCTA"                                                           


* Drop coordinates due to Meta 
drop longitude latitude

compress
save "`public_replication_FB_data'/social_capital_college.dta", replace


*==============================================================================*
**## 4.2 Clean public covariate data 
*==============================================================================*

use "`networks'/County Level Social Capital/raw data/college_characteristics/college_characteristics.dta", clear

replace college = college * 100
label variable college "College ID"


rename name college_name
rename county county_name
rename cfips county
rename count mean_students_per_cohort


drop exp_instr_2012 exp_instr_2000                                              // variables not used and no informative labels - not worth the trouble to hunt down what these are

compress
save "`public_replication_covariates'/college_characteristics.dta", replace



*==============================================================================*
**## 4.3 Clean data from Chetty et al. (2020b)
*==============================================================================*

use "`networks'/County Level Social Capital/raw data/college_characteristics/mrc_table3.dta", clear
compress 
save "`public_replication_covariates'/chetty_2020b_QJE_table_3.dta", replace 


use "`networks'/County Level Social Capital/raw data/college_characteristics/mrc_table11.dta", clear
compress 
save "`public_replication_covariates'/chetty_2020b_QJE_opeid_superopeid_crosswalk.dta", replace 


********************************************************************************
**# 5. Clean friendship matrix data 
********************************************************************************

import delimited "${dropbox}/outside/Networks and Social Mobility/Meta Social Capital Data Sharing (local copy)/Social Capital Data/100x100Matrix_SI_Fig16.csv", clear

drop ds 

rename ego_decile own_ses_percentile 
label var own_ses_percentile "Individuals' Own SES Percentile "

forval val = 1(1)100 {
	rename friend_prob_d`val' friend_prob_p`val'
	label var friend_prob_p`val' "Proportion of friends at SES percentile `val'"
}


compress
save "`public_replication_FB_data'/100_x_100_friendship_matrix.dta", replace





